"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FormMethods = void 0;
var index_1 = __importDefault(require("lodash.isobject/index"));
// import { AxiosError, AxiosResponse } from 'axios';
var Errors_1 = __importDefault(require("./Errors"));
// import Request from './Request';
var FormMethods;
(function (FormMethods) {
    FormMethods["POST"] = "post";
    FormMethods["PATCH"] = "patch";
    FormMethods["PUT"] = "put";
})(FormMethods = exports.FormMethods || (exports.FormMethods = {}));
var Form = /** @class */ (function () {
    // request: Request;
    /**
     * Create a new Form instance.
     */
    function Form(data, config) {
        if (config === void 0) { config = {}; }
        this.config = __assign({ resetAfterSend: true, removeNullValues: true, method: FormMethods.POST }, config);
        this.data = data;
        this.originalData = __assign({}, data);
        this.errors = new Errors_1.default();
        if (this.config.method !== FormMethods.POST) {
            this.addField('_method', this.config.method);
        }
        // @ts-ignore
        // this.request = Request;
        Object.preventExtensions(this);
        return new Proxy(this, {
            set: function (target, name, value) {
                var propertyKey = String(name);
                if (Object.keys(target.data).includes(propertyKey)) {
                    // eslint-disable-next-line no-param-reassign
                    target.data[propertyKey] = value;
                    return true;
                }
                throw new Error("Form data does not have '" + propertyKey + "' field. Add the field first.");
            },
        });
    }
    /**
     * Add a new field with value to the form.
     */
    Form.prototype.addField = function (field, value) {
        this.originalData[field] = value;
        this.data[field] = value;
    };
    /**
     * Get FormData object.
     */
    Form.prototype.getFormData = function () {
        var _this = this;
        var formData = new FormData();
        Object.keys(this.data).forEach(function (field) {
            var value = _this.data[field];
            if (value === null && _this.config.removeNullValues) {
                return;
            }
            if (typeof value === 'boolean') {
                formData.append(field, Number(value).toString());
            }
            else if (Array.isArray(value)) {
                value.forEach(function (item) {
                    formData.append(field + "[]", item);
                });
            }
            else if (index_1.default(value) && !(value instanceof File)) {
                Object.keys(value).forEach(function (key) {
                    // @ts-ignore
                    formData.append(field + "[" + key + "]", value[key]);
                });
            }
            else {
                formData.append(field, value);
            }
        });
        return formData;
    };
    Form.prototype.reset = function () {
        var _this = this;
        Object.keys(this.originalData).forEach(function (field) {
            _this.data[field] = _this.originalData[field];
        });
        this.errors.clear();
    };
    Form.prototype.serialize = function () {
        var _this = this;
        var json = {};
        Object.keys(this.originalData).forEach(function (field) {
            json[field] = _this.data[field];
        });
        return json;
    };
    return Form;
}());
exports.default = Form;
//# sourceMappingURL=Form.js.map