"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/* eslint-disable max-len */
var axios_1 = __importDefault(require("axios"));
var Request = /** @class */ (function () {
    function Request(config) {
        var _this = this;
        if (config === void 0) { config = {}; }
        this.config = __assign({ autoRequestCsrfCookie: true, csrfCookieUrl: '/sanctum/csrf-cookie' }, config);
        this.service = axios_1.default;
        this.service.defaults.withCredentials = true;
        this.service.defaults.headers.common['X-Requested-With'] = 'XMLHttpRequest';
        this.service.interceptors.response.use(function (response) { return response; }, function (error) {
            // 419 error means that the CSRF token has timed out
            // in that case if the config autoRequestCsrfCookie is set to 'true',
            // we try to receive new token and retry the request.
            if (error.response.status === 419) {
                if (_this.config.autoRequestCsrfCookie && typeof config.csrfCookieUrl === 'string') {
                    return _this.get(config.csrfCookieUrl)
                        .then(function () { return _this.service.request(error.config); });
                }
            }
            if (typeof config.errorCallbacks !== 'undefined') {
                Object.keys(config.errorCallbacks).forEach(function (key) {
                    var errorCode = Number.parseInt(key, 10);
                    if (error.response.status === errorCode) {
                        // @ts-ignore
                        config.errorCallbacks[errorCode](error);
                    }
                });
            }
            return Promise.reject(error);
        });
    }
    Request.prototype.get = function (url, config) {
        return this.service.get(url, config);
    };
    Request.prototype.post = function (url, data, config) {
        return this.service.post(url, data, config);
    };
    Request.prototype.patch = function (url, data, config) {
        return this.service.patch(url, data, config);
    };
    Request.prototype.put = function (url, data, config) {
        return this.service.put(url, data, config);
    };
    Request.prototype.delete = function (url, config) {
        return this.service.delete(url, config);
    };
    return Request;
}());
exports.default = Request;
//# sourceMappingURL=Request.js.map